@@ -1,4 +1,4 @@
-/*	$Id: ClassModem.h,v 1.22 2006/07/05 15:54:23 aidan Exp $ */
+/*	$Id: ClassModem.h,v 1.26 2007/06/05 17:30:16 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -31,6 +31,7 @@
 #include <stdarg.h>
 #include "Str.h"
 #include "CallID.h"
+#include "Status.h"
 
 class ModemServer;
 class ModemConfig;
@@ -68,6 +69,7 @@ typedef struct {
 #define	ESC_DELAY	(0x80|0x04)	// delay period of time
 #define	ESC_WAITFOR	(0x80|0x08)	// wait for modem response
 #define	ESC_FLUSH	(0x80|0x10)	// flush input queue
+#define	ESC_PLAY	(0x80|0x20)	// play (voice) file
 
 #ifdef OFF
 #undef OFF			// workaround for SCO
@@ -108,7 +110,7 @@ public:
 	CALLTYPE_ERROR	= 4,	// error deducing type of incoming call
 	CALLTYPE_DONE	= 5	// subprocess completed call handling
     };
-    static const char* callTypes[5];
+    static const char* callTypes[6];
 
     enum {			// ClassModem::SpeakerVolume
 	OFF	= 0,		// nothing
@@ -155,10 +157,10 @@ public:
 	ANSTYPE_DATA	= 1,	// data call
 	ANSTYPE_FAX	= 2,	// fax call
 	ANSTYPE_VOICE	= 3,	// voice call
-	ANSTYPE_EXTERN	= 3,	// any kind of call, but answered externally
-	ANSTYPE_DIAL	= 4	// dial out to receive (pseudo poll)
+	ANSTYPE_DIAL	= 4,	// dial out to receive (pseudo poll)
+	ANSTYPE_EXTERN	= 5	// any kind of call, but answered externally
     };
-    static const char* answerTypes[5];
+    static const char* answerTypes[6];
 
     enum {			// ClassModem::ATResponse
 	AT_NOTHING	= 0,	// for passing as a parameter
@@ -177,7 +179,8 @@ public:
 	AT_DLEETX	= 13,	// dle/etx characters
 	AT_DLEEOT	= 14,	// dle+eot characters (end of transmission)
 	AT_XON		= 15,	// xon character
-	AT_OTHER	= 16	// unknown response (not one of above)
+	AT_DTMF		= 16,	// DTMF detection
+	AT_OTHER	= 17	// unknown response (not one of above)
     };
 private:
     ModemServer& server;	// server for getting to device
@@ -201,7 +204,7 @@ protected:
     fxStr	revQueryCmd;	// product revision identification command
 
     static const char* serviceNames[9];	 // class 2 services
-    static const char* callStatus[10];	 // printable call status
+    static Status callStatus[10];	 // printable call status
     static const char* ATresponses[17];
 
     ClassModem(ModemServer&, const ModemConfig&);
@@ -216,8 +219,8 @@ protected:
     bool doQuery(const fxStr& queryCmd, fxStr& result, long ms = 30*1000);
 // dial/answer interactions with derived classes
     virtual const AnswerMsg* findAnswer(const char* s);
-    virtual CallType answerResponse(fxStr& emsg);
-    virtual CallStatus dialResponse(fxStr& emsg) = 0;
+    virtual CallType answerResponse(Status& eresult);
+    virtual CallStatus dialResponse(Status& eresult) = 0;
     virtual bool isNoise(const char*);
 // miscellaneous
     void	modemSupports(const char* fmt, ...);
@@ -298,19 +301,19 @@ public:
     /*
      * Send support:
      *
-     * if (dial(number, params, emsg) == OK) {
+     * if (dial(number, params, eresult) == OK) {
      *	  ...do stuff...
      * }
      * hangup();
      */
     virtual bool dataService();
-    virtual CallStatus dial(const char* number, fxStr& emsg);
+    virtual CallStatus dial(const char* number, Status& eresult);
 
     /*
      * Receive support:
      *
      * if (waitForRings(nrings, ctype, cid)) {	// wait before answering phone
-     *    case (answerCall(type, emsg)) {
+     *    case (answerCall(type, eresult)) {
      *    CALLTYPE_FAX:
      *	        ...do fax kinds of things...
      *      break;
@@ -327,8 +330,13 @@ public:
      * at any time in this procedure.
      */
     virtual bool waitForRings(u_short rings, CallType&, CallID&);
-    virtual CallType answerCall(AnswerType, fxStr& emsg, const char* dialnumber = NULL);
+    virtual CallType answerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
     virtual void answerCallCmd(CallType);
+
+    /*
+     * Voice support
+     */
+    virtual void playFile (u_int id);
 };
 inline long ClassModem::getDataTimeout() const		{ return dataTimeout; }
 inline const fxStr& ClassModem::getModel() const	{ return modemModel; }
