@@ -1,4 +1,4 @@
-/*	$Id: FaxModem.h,v 1.38 2006/03/17 16:47:08 lhoward Exp $ */
+/*	$Id: FaxModem.h,v 1.45 2007/06/04 17:11:07 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -44,6 +44,7 @@ class FaxServer;
 // NB: these would be enums in the FaxModem class
 //     if there were a portable way to refer to them!
 typedef unsigned int RTNHandling;       // RTN signal handling method 
+typedef unsigned int BadPageHandling;	// bad page (received) handling method 
 typedef unsigned int JBIGSupport;	// JBIG support available
 
 /*
@@ -71,6 +72,7 @@ private:
 // phase c data receive & copy quality checking
     u_int	cblc;		// current count of consecutive bad lines
     bool	lastRowBad;	// last decoded row was bad
+    u_long	linesWereA4Width;// count of lines measuring 1728 pel
 
     u_long	recvEOLCount;	// EOL count for received page
     u_long	recvBadLineCount;
@@ -84,6 +86,8 @@ private:
     int		decoderFd[2];	// file descriptors for the decoder pipe
     int		counterFd[2];	// file descriptors for the counter pipe
     pid_t	decoderPid;	// process id for the decoding process
+    u_char	parserBuf[16];	// buffer used for parsing JBIG and JPEG
+    u_long	parserCount[3];	// counters used in parsing JBIG and JPEG
 
     void	flushEncodedData(TIFF*, tstrip_t, const u_char*, u_int);
     void	flushRawData(TIFF*, tstrip_t, const u_char*, u_int);
@@ -119,13 +123,17 @@ protected:
     void	recvTrace(const char* fmt, ...);
     void	copyQualityTrace(const char* fmt, ...);
     void	traceModemParams();
-    void	tracePPR(const char* dir, u_int ppr);
-    void	tracePPM(const char* dir, u_int ppm);
+    void	traceFCF(const char* dir, u_int fcf);
+    void	parseJPEGStream(u_char c);
+    void	fixupJPEG(TIFF* tif);
+    void	parseJBIGStream(u_char c);
+    void	parseJBIGBIH(u_char* buf);
+    void	clearSDNORMCount();
 // server-related stuff
     bool	getHDLCTracing();
     bool	getECMTracing();
     FaxSendStatus sendSetupParams(TIFF*, Class2Params&,
-		    FaxMachineInfo&, fxStr&);
+		    FaxMachineInfo&, Status&);
     void	recvTSI(const fxStr&);
     void	recvPWD(const fxStr&);
     void	recvSUB(const fxStr&);
@@ -136,11 +144,11 @@ protected:
     void	recvStartPage(TIFF* tif);
     void	recvResetPage(TIFF* tif);
     u_int	decodePageChop(const fxStr& pph, const Class2Params&);
-    bool	decodePPM(const fxStr& pph, u_int& ppm, fxStr& emsg);
+    bool	decodePPM(const fxStr& pph, u_int& ppm, Status& eresult);
     void	notifyPageSent(TIFF*);
 // phase c data receive & copy quality checking
     bool	recvPageDLEData(TIFF* tif, bool checkQuality,
-		    const Class2Params& params, fxStr& emsg);
+		    const Class2Params& params, Status& eresult);
     void	setupStartPage(TIFF* tif, const Class2Params& params);
     void	recvEndPage(TIFF* tif, const Class2Params& params);
     void	writeECMData(TIFF*, u_char*, u_int, const Class2Params&, u_short);
@@ -175,6 +183,11 @@ public:
         RTN_IGNORE     = 2,         // ignore error and send next page
         RTN_RETRANSMITIGNORE = 3    // retransmit but ignore error instead of hanging up
     };
+    enum {			// FaxModem::BadPageHandling
+	BADPAGE_RTN     = 0,	// send RTN, expect a retransmission
+	BADPAGE_DCN     = 1,	// send DCN, expect a disconnection
+	BADPAGE_RTNSAVE = 2	// send RTN, but save the page
+    };
     enum {			// FaxModem::JBIGSupport
 	JBIG_NONE = 0,		    // no JBIG support
 	JBIG_RECV = 1,		    // receive-only JBIG support
@@ -234,14 +247,15 @@ public:
      * for doing things like keeping cover pages & documents in a
      * single T.30 document.
      */
-    virtual bool faxService(bool enableV34) = 0;
-    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, fxStr& emsg);
+    virtual bool faxService(bool enableV34, bool enableV17) = 0;
+    virtual bool sendSetup(FaxRequest&, const Class2Params& dis, Status&
+		    eresult);
     virtual void sendBegin();
     virtual FaxSendStatus getPrologue(Class2Params&,
-	bool& hasDoc, fxStr& emsg, u_int& batched) = 0;
+	bool& hasDoc, Status& eresult, u_int& batched) = 0;
     virtual void sendSetupPhaseB(const fxStr& pwd, const fxStr& sub);
     virtual FaxSendStatus sendPhaseB(TIFF*, Class2Params&, FaxMachineInfo&,
-	fxStr& pph, fxStr& emsg, u_int& batched) = 0;
+	fxStr& pph, Status& eresult, u_int& batched) = 0;
     virtual void sendEnd();
     virtual void sendAbort() = 0;
     // query interfaces for optional state
@@ -277,10 +291,10 @@ public:
      * }
      */
     virtual bool setupReceive() = 0;
-    virtual bool recvBegin(fxStr& emsg);
-    virtual bool recvEOMBegin(fxStr& emsg);
-    virtual bool recvPage(TIFF*, u_int& ppm, fxStr& em, const fxStr& id) = 0;
-    virtual bool recvEnd(fxStr& emsg) = 0;
+    virtual bool recvBegin(Status& eresult);
+    virtual bool recvEOMBegin(Status& eresult);
+    virtual bool recvPage(TIFF*, u_int& ppm, Status& result, const fxStr& id) = 0;
+    virtual bool recvEnd(Status& eresult) = 0;
     virtual void recvAbort() = 0;
     virtual void recvSucceeded();
     virtual void pokeConfig(bool isSend) = 0;
@@ -305,9 +319,9 @@ public:
      *
      * (i.e. it's just like a receive operation.)
      */
-    virtual bool requestToPoll(fxStr& emsg) = 0;
+    virtual bool requestToPoll(Status& eresult) = 0;
     virtual bool pollBegin(
 	const fxStr& cig, const fxStr& sep, const fxStr& pwd,
-	fxStr& emsg);
+	Status& eresult);
 };
 #endif /* _FAXMODEM_ */
