@@ -1,4 +1,4 @@
-/*	$Id: Getty.h,v 1.3 2005/01/01 21:27:15 lhoward Exp $ */
+/*	$Id: Getty.h,v 1.4 2007/05/15 15:52:03 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -31,6 +31,7 @@
  * System V, BSD, etc. are derived from this. 
  */
 #include "Str.h"
+#include "CallID.h"
 
 const int GETTY_MAXARGS		= 64;	// max args passed to getty
 
@@ -55,7 +56,7 @@ protected:
 public:
     virtual ~Getty();
 					// setup arguments for getty process
-    void setupArgv(const char* args, const fxStr&, const fxStr&);
+    void setupArgv(const char* args, const CallID& callid);
 					// run getty process
     virtual void run(int fd, bool parentIsInit);
     virtual bool wait(int& status, bool block = false);
