@@ -1,4 +1,4 @@
-/*	$Id: Job.h,v 1.7 2006/03/28 18:23:42 aidan Exp $ */
+/*	$Id: Job.h,v 1.10 2007/05/04 17:28:32 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -35,6 +35,7 @@
 #include "Str.h"
 
 typedef unsigned int JobStatus;
+class Batch;
 class Modem;
 class Job;
 class FaxRequest;
@@ -60,22 +61,7 @@ public:
     ~JobTTSHandler();
     void timerExpired(long, long);
 };
-class JobPrepareHandler : public IOHandler {
-private:
-    Job& job;
-public:
-    JobPrepareHandler(Job&);
-    ~JobPrepareHandler();
-    void childStatus(pid_t, int);
-};
-class JobSendHandler : public IOHandler {
-private:
-    Job& job;
-public:
-    JobSendHandler(Job&);
-    ~JobSendHandler();
-    void childStatus(pid_t, int);
-};
+
 
 /*
  * This does sligltly more than the other PID handlers.
@@ -103,8 +89,6 @@ class Job : public QLink {
 private:
     JobKillHandler	killHandler;	// Dispatcher handler for kill timeout
     JobTTSHandler	ttsHandler;	// Dispatcher handler for tts timeout
-    JobPrepareHandler	prepareHandler;	// Dispatcher handler for job prep work
-    JobSendHandler	sendHandler;	// Dispatcher handler for job send work
     JobCtrlHandler	ctrlHandler;	// Dispatcher handler for job control work
 
     static JobDict registry;
@@ -144,24 +128,20 @@ public:
     fxStr	dest;		// canonical destination identity
     fxStr	device;		// modem to be used
     fxStr	commid;		// commid of last call
-    Job*	dnext;		// linked list by destination
     Modem*	modem;		// modem/server currently assigned to job
     QLink	triggers;	// waiting specifically on this job
 
-    Job*	bprev;		// prev in batch
-    Job*	bnext;		// next in batch
-    FaxRequest*	breq;		// pointer to request used by batching support
     JobControlInfo* jci;	// Job control information
 
     Job(const FaxRequest&);
     void update(const FaxRequest& req);
     ~Job();
 
-    void remove(void);
-
     static Job* getJobByID(const fxStr& jobid);
     static fxStr jobStatusName(const JobStatus);
 
+    bool higherPriority(const Job& other) const;
+
     void startKillTimer(long sec);
     void stopKillTimer();
 
@@ -174,8 +154,6 @@ public:
 
     void encode(fxStackBuffer&) const;	// encode in JobExt format
 
-    Job* bfirst();			// first job in batch
-
     const JobControlInfo& getJCI (void) const;
 };
 
