@@ -1,4 +1,4 @@
-/*	$Id: ModemConfig.h,v 1.44 2006/07/21 08:46:17 aidan Exp $ */
+/*	$Id: ModemConfig.h,v 1.55 2007/06/05 17:30:16 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -32,6 +32,7 @@
 #include "FaxModem.h"
 
 #include "Array.h"
+#include "StrArray.h"
 
 class id_config
 {
@@ -57,6 +58,7 @@ private:
     u_int	getSpeed(const char* value);
     u_int	getDataFormat(const char* value);
     u_int       getRTNHandling(const char* cp);
+    u_int       getBadPageHandling(const char* cp);
     u_int       getJBIGSupport(const char* cp);
     ECMType	getECMType(const char* cp);
 
@@ -150,8 +152,8 @@ public:
     fxStr	class1EOPWaitCmd;	// cmd to stop and wait prior to EOP
     fxStr	class1SwitchingCmd;	// after recv HDLC and before sending
     fxStr	class1MsgRecvHackCmd;	// cmd to avoid +FCERROR before image
+    fxStr	class1TCFRecvHackCmd;	// cmd to avoid +FCERROR before TCF
     u_int	class1TCFRecvTimeout;	// timeout receiving TCF
-    u_int	class1TrainingRecovery;	// delay (ms) after failed training
     u_int	class1RecvAbortOK;	// if non-zero, OK sent after recv abort
     u_int	class1RMPersistence;	// how many times to persist through +FCERROR
     u_int	class1Resolutions;	// resolutions support
@@ -161,17 +163,23 @@ public:
     u_int	class1TCFMinRun;	// min length of zero run for TCF check
     u_int	class1TMConnectDelay;	// delay (ms) after +FTM CONNECT
     u_int	class1ECMFrameSize;	// ECM frame size for transmission
+    u_int	class1PageLengthSupport;// page length support
+    u_int	class1PageWidthSupport;	// page width support
     bool	class1GreyJPEGSupport;	// Greyscale JPEG support
     bool	class1ColorJPEGSupport;	// Full-color JPEG support
     bool	class1ECMSupport;	// support T.30-A ECM
+    bool	class1MRSupport;	// support 2-D MR
+    bool	class1MMRSupport;	// support 2-D MMR
     bool	class1PersistentECM;	// continue to correct
-    bool	class1TCFRecvHack;	// deliberately look for V.21 disconnect
     bool	class1ValidateV21Frames;// check received FCS values in V.21
+    bool	class1ModemHasDLEBug;;	// modem doesn't double-up DLEs in V.21
+    bool	class1HasRHConnectBug;;	// modem reports CONNECT after +FRH=3 to non-V.21-HDLC data
 					// for class 2 and 2.0:
     fxStr	class2Cmd;		// cmd for setting Class 2/2.0
     fxStr	class2DCCQueryCmd;	// cmd to query modem capabilities
     fxStr	class2CQQueryCmd;	// cmd to query copy quality checking
     fxStr	class2BORCmd;		// cmd to set bit order
+    fxStr	class2DisableV17Cmd;	// cmd to disable V.17 support
     fxStr	class2RELCmd;		// cmd to enable byte-aligned EOL
     fxStr	class2CQCmd;		// cmd to setup copy quality checking
     fxStr	class2AbortCmd;		// cmd to abort a session
@@ -192,6 +200,7 @@ public:
     fxStr	class2HFLOCmd;		// cmd to setup hardware flow control
     fxStr	class2MINSPCmd;		// cmd to setup min transmit speed
     fxStr	class2RecvDataTrigger;	// send to start recv
+    bool	class2JPEGSupport;	// use JPEG support as reported by the modem
     bool	class2XmitWaitForXON;	// wait for XON before send
     bool	class2RTFCC;		// real-time fax compression conversion
     bool	class2SendRTC;		// append RTC to page data on transmit
@@ -229,9 +238,12 @@ public:
     bool	useJobTagLine;		// Use Job tagline or use conf taglineformat
 
     RTNHandling rtnHandling;            // RTN signal handling method
+    BadPageHandling badPageHandling;	// bad page (received) handling method
     JBIGSupport	class1JBIGSupport;	// monochrome JBIG support
     bool	saveUnconfirmedPages;	// don't delete unconfirmed pages
     
+    fxStrArray	playList;		// List of files for ESC_PLAY
+
     					// Distinctive ring data as sequences of DRON/DROF intervals
     struct {
     	int cadence[5];                 // the ring cadence as a five-dimensional vector
