@@ -1,4 +1,4 @@
-/*	$Id: ModemServer.h,v 1.13 2006/03/17 16:47:10 lhoward Exp $ */
+/*	$Id: ModemServer.h,v 1.15 2007/06/04 17:11:07 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -137,6 +137,7 @@ protected:
     virtual fxStr getModemCapabilities() const;
 // modem i/o support
     void	timerExpired(long, long);
+    void	sendDLEETX();
     int		getModemLine(char buf[], u_int bufSize, long ms = 0);
     int		getModemChar(long ms = 0);
     int		getModemBit(long ms = 0);
@@ -160,7 +161,7 @@ protected:
     bool	modemStopOutput();
 // modem driver interfaces
     bool	modemWaitForRings(u_short rings, CallType&, CallID&);
-    CallType	modemAnswerCall(AnswerType, fxStr&, const char* dialnumber = NULL);
+    CallType	modemAnswerCall(AnswerType, Status& eresult, const char* dialnumber = NULL);
     void	modemAnswerCallCmd(CallType);
     void	modemFlushInput();
     void	modemHangup();
