@@ -1,4 +1,4 @@
-/*	$Id: ServerConfig.h,v 1.6 2004/03/05 02:41:39 lhoward Exp $ */
+/*	$Id: ServerConfig.h,v 1.8 2005/05/09 15:28:42 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -43,6 +43,11 @@ public:
 	fxStr ServerConfig::* p;
 	const char*	 def;		// NULL is shorthand for ""
     };
+    struct S_booltag {
+	const char*	 name;
+	bool ServerConfig::* p;
+	bool		 def;		// NULL is shorthand for ""
+    };
     struct S_numbertag {
 	const char*	 name;
 	u_int ServerConfig::*p;
@@ -73,6 +78,7 @@ private:
     fxBoolArray* acceptPWD;		// accept/reject matched PWD
     fxStr	logFacility;		// syslog facility to direct trace msgs
 
+    static S_booltag bools[];
     static S_stringtag strings[];
     static S_numbertag numbers[];
     static S_filemodetag filemodes[];
@@ -98,7 +104,6 @@ public:
     SpeakerVolume speakerVolume;	// volume control
     fxStr	qualifyTSI;		// if set, no recv w/o acceptable tsi
     fxStr	qualifyPWD;		// if set, no recv w/o acceptable PWD
-    u_int	noCarrierRetrys;	// # times to retry on no carrier
     mode_t	recvFileMode;		// protection mode for received files
     mode_t	deviceMode;		// protection mode for modem device
     mode_t	logMode;		// protection mode for log files
@@ -110,6 +115,8 @@ public:
     u_int	requeueTTS[9];		// requeue intervals[CallStatus code]
     u_int	requeueProto;		// requeue interval after protocol error
     u_int	requeueOther;		// requeue interval after other problem
+    u_int	retryMAX[9];		// number of retries[CallStatus code]
+    u_int	retryOther;		// number of retries after other problem
     u_int	pollModemWait;		// polling interval in modem wait state
     u_int	pollLockWait;		// polling interval in lock wait state
     u_int	maxRecvPages;		// max pages to accept on receive
@@ -117,6 +124,7 @@ public:
     fxStr	localIdentifier;	// to use in place of FAXNumber
     fxStr	FAXNumber;		// phone number
     u_int	maxSetupAttempts;	// # times to try initializing modem
+    bool	batchLogs;		// Batch session logs togther or not
 
     virtual ~ServerConfig();
 
