@@ -1,4 +1,4 @@
-/*	$Id: faxApp.h,v 1.5 2004/02/28 18:54:19 lhoward Exp $ */
+/*	$Id: faxApp.h,v 1.6 2007/03/09 20:54:11 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -80,7 +80,7 @@ public:
     static const fxStr quote;
     static const fxStr enquote;
 
-    bool runCmd(const char* cmd, bool changeIDs = false, IOHandler* waiter = NULL);
+    static bool runCmd(const char* cmd, bool changeIDs = false, IOHandler* waiter = NULL);
 };
 inline bool faxApp::isRunning(void) const	{ return running; }
 
