@@ -1,4 +1,4 @@
-/*	$Id: faxGettyApp.h,v 1.15 2006/03/17 16:47:10 lhoward Exp $ */
+/*	$Id: faxGettyApp.h,v 1.16 2007/06/04 17:11:07 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -106,10 +106,10 @@ private:
     bool	setupModem(bool isSend);
     void	discardModem(bool dropDTR);
 // inbound call handling
-    bool	processCall(CallType ctype, fxStr& emsg, const CallID& callid);
+    bool	processCall(CallType ctype, Status& eresult, const CallID& callid);
     CallType	runGetty(const char* what,
 		    Getty* (*newgetty)(const fxStr&, const fxStr&),
-		    const char* args, fxStr &emsg,
+		    const char* args, Status &eresult,
                     bool keepLock, const CallID& callid, 
 		    bool keepModem = false);
     void	setRingsBeforeAnswer(int rings);
@@ -118,7 +118,7 @@ private:
     void	answerPhoneCmd(AnswerType, const char* dialnumber = NULL);
     void	answerPhone(AnswerType, CallType, const CallID& callid, const char* dialnumber = NULL);
     void	answerCleanup();
-    bool	answerCall(AnswerType atype, CallType& ctype, fxStr& emsg, const CallID& callid, const char* dialnumber = NULL);
+    bool	answerCall(AnswerType atype, CallType& ctype, Status& eresult, const CallID& callid, const char* dialnumber = NULL);
 
     friend void AnswerTimeoutHandler::timerExpired(long, long);
 // miscellaneous stuff
