@@ -1,4 +1,4 @@
-/*	$Id: MsgFmt.h,v 1.3 2003/11/20 21:23:15 aidan Exp $ */
+/*	$Id: MsgFmt.h,v 1.3.4.2 2007/09/14 16:31:39 pfournier Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -51,12 +51,13 @@ struct MsgFmt {
     virtual bool setConfigItem(const char* tag, const char* value);
 
     static bool getLine(FILE* fd, fxStackBuffer& buf);
+    static fxStr stripComments(const fxStr& s);
 
     const fxStr* findHeader(const fxStr& name) const;
     u_int headerCount(void);
     fxStr mapHeader(const fxStr& name);
     void parseHeaders(FILE* fd, u_int& lineno);
-    void formatHeaders(TextFormat& fmt);
+    bool formatHeaders(TextFormat& fmt);
     void showItalic(TextFormat& fmt, const char* cp);
 };
 #endif /* _MsgFmt_ */
