@@ -1,4 +1,4 @@
-/*	$Id: HylaFAXServer.h,v 1.17 2006/06/12 18:28:54 aidan Exp $ */
+/*	$Id: HylaFAXServer.h,v 1.20 2007/06/04 17:12:02 aidan Exp $ */
 /*
  * Copyright (c) 1995-1996 Sam Leffler
  * Copyright (c) 1995-1996 Silicon Graphics, Inc.
@@ -40,13 +40,6 @@
 
 #include "config.h"
 
-#ifdef HAVE_PAM
-extern "C" {
-#include <security/pam_appl.h>
-#include <grp.h>
-}
-#endif // HAVE_PAM
-
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <dirent.h>
@@ -123,7 +116,7 @@ enum Token {
     T_MAXTRIES,	 T_MINBR,	T_MODEM,	T_NDIALS,	T_NOTIFY,
     T_NOTIFYADDR,T_NPAGES,	T_NTRIES,	T_OWNER,	T_PAGECHOP,
     T_PAGELENGTH,T_PAGEWIDTH,	T_PASSWD,	T_POLL,		T_REGARDING,
-    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,
+    T_RETRYTIME, T_SCHEDPRI,	T_SENDTIME,	T_STATE,	T_STATUS,	T_STATUSCODE, T_ERRORCODE,
     T_SUBADDR,	 T_TAGLINE,	T_TOTDIALS,	T_TOTPAGES,	T_TOTTRIES,
     T_TO_COMPANY,T_TO_LOCATION,	T_TO_USER,	T_TO_VOICE,	T_TSI,		T_USE_CONTCOVER,
     T_USE_ECM,	 T_USE_TAGLINE,	T_USE_XVRES,	T_USRKEY,	T_VRES,
@@ -216,11 +209,6 @@ protected:
     /*
      * User authentication and login-related state.
      */
-#ifdef HAVE_PAM
-	pam_handle_t *pamh;		// handle to current pam session
-	bool	pam_chrooted;	// if already chrooted, PAM gets disabled
-#endif
-
     fxStr	passwd;			// encrypted user password
     fxStr	adminwd;		// encrypted passwd for admin privileges
     u_int	uid;			// client's ID
@@ -229,7 +217,7 @@ protected:
     u_int	adminAttempts;		// number of failed admin attempts
     u_int	maxAdminAttempts;	// admin failures before server exits
     fxStr	the_user;		// name of user
-	fxStr   admingroup;			// name of local user group that is allowed
+    fxStr	admingroup;			// name of local user group that is allowed
 								// to administer the fax server
     IDCache*	idcache;		// fax UID -> name mapping table
     /*
@@ -349,12 +337,18 @@ protected:
     void setFileOwner(const char* filename);
 
     void loginRefused(const char* why);
-	bool pamCheck(const char* user=NULL, const char* pass=NULL);
-	bool pamIsAdmin(const char* user=NULL);
-	void pamEnd(int pamret);
+
     bool checkUser(const char*);
-    bool checkuser(FILE*, const char *name);
-    bool checkuser(const char *name);
+    bool checkPasswd(const char*);
+
+    bool checkuserHosts(FILE*, const char *name);
+    bool checkuserPAM(const char *name);
+
+    bool checkpasswdHosts(const char* passwd);
+    bool checkpasswdPAM(const char* passwd);
+
+    bool isAdminGroup(const char* user=NULL);
+
     void login(int code);
     void end_login(void);
     virtual void dologout(int status);
