@@ -1,4 +1,4 @@
-/*	$Id: Sys.h,v 1.6 2003/02/08 22:49:58 darren Exp $ */
+/*	$Id: Sys.h,v 1.7 2007/05/08 20:28:47 aidan Exp $ */
 /*
  * Copyright (c) 1994-1996 Sam Leffler
  * Copyright (c) 1994-1996 Silicon Graphics, Inc.
@@ -78,6 +78,8 @@ public:
 	{ return  ::unlink(filename); }
     static int access(const char* path, int mode)
 	{ return ::access(path, mode); }
+    static int rmdir(const char* path)
+	{ return ::rmdir(path); }
 
     static int chmod(const char* file, mode_t m)
 	{ return ::chmod(file, m); }
@@ -134,6 +136,8 @@ public:
         return fd;
     }
 
+    static char* mkdtemp(char* templ)	{ return ::mkdtemp(templ); }
+
     static FILE* tmpfile()	{ return ::tmpfile(); }
     static FILE* fopen(const char* filename, const char* mode)
 	{ return ::fopen(filename, mode); }
