@@ -1,4 +1,4 @@
-/*	$Id: t.30.h,v 1.8 2005/09/27 19:29:12 lhoward Exp $ */
+/*	$Id: t.30.h,v 1.9 2006/04/03 15:38:16 aidan Exp $ */
 /*
  * Copyright (c) 1990-1996 Sam Leffler
  * Copyright (c) 1991-1996 Silicon Graphics, Inc.
@@ -62,8 +62,8 @@
 
 #define	TCF_DURATION	1500		// 1.5 seconds
 
-// this is our defined NSF manufacturer code in reverse bit-order
-#define HYLAFAX_NSF	"\255\000\125"
+// this is our defined NSF manufacturer code
+#define HYLAFAX_NSF	"\xB5\x00\xAA"
 
 /*
  * Facsimile control field (FCF) values
